@@ -1,5 +1,5 @@
 package Chess::ELO::FEDA;
-$Chess::ELO::FEDA::VERSION = '0.02';
+$Chess::ELO::FEDA::VERSION = '0.03';
 use strict;
 use warnings;
 
@@ -299,7 +299,7 @@ Chess::ELO::FEDA - Download FEDA ELO (L<http://www.feda.org>) into differents ba
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -311,6 +311,24 @@ version 0.02
       -verbose  => 1
    );
 
+=head1 DESCRIPTION
+
+The main idea of this module consists on build a SQL format from the XLS
+downloaded from the URL provided. All players information are loaded into
+"elo_feda" table, according this script:
+
+   CREATE TABLE elo_feda(
+      feda_id integer primary key, 
+      surname varchar(32) not null,
+      name    varchar(32), 
+      fed     varchar(8), 
+      rating  integer, 
+      games   integer, 
+      birth   integer, 
+      title   varchar(16), 
+      flag    varchar(8)
+   );
+
 =head1 METHODS
 
 =head2 new (%OPTS)
@@ -348,17 +366,17 @@ main file expected into the package is the XLS
 
 =head2 cleanup
 
-Unlink the files dowloaded for this downloader
+Unlink the files dowloaded for this downloader (the XLS file)
 
 =head2 download
 
 Download the ZIP file from the -url parameter. Extract the XLS file to the
-target_folder (which must exists)
+target_folder (which must exists).
 
 =head2 parse
 
 Parse and transform the XLS input file to the proper backend, according the
--target parameter.
+-target parameter. It relies on DBD::* in order to build the file.
 
 =head2 run
 
